@@ -41,15 +41,28 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-SendSSHPublicKeyRequestRequestTypeDef = TypedDict(
-    "SendSSHPublicKeyRequestRequestTypeDef",
+_RequiredSendSSHPublicKeyRequestRequestTypeDef = TypedDict(
+    "_RequiredSendSSHPublicKeyRequestRequestTypeDef",
     {
         "InstanceId": str,
         "InstanceOSUser": str,
         "SSHPublicKey": str,
-        "AvailabilityZone": NotRequired[str],
     },
 )
+_OptionalSendSSHPublicKeyRequestRequestTypeDef = TypedDict(
+    "_OptionalSendSSHPublicKeyRequestRequestTypeDef",
+    {
+        "AvailabilityZone": str,
+    },
+    total=False,
+)
+
+
+class SendSSHPublicKeyRequestRequestTypeDef(
+    _RequiredSendSSHPublicKeyRequestRequestTypeDef, _OptionalSendSSHPublicKeyRequestRequestTypeDef
+):
+    pass
+
 
 SendSSHPublicKeyResponseTypeDef = TypedDict(
     "SendSSHPublicKeyResponseTypeDef",
@@ -60,14 +73,28 @@ SendSSHPublicKeyResponseTypeDef = TypedDict(
     },
 )
 
-SendSerialConsoleSSHPublicKeyRequestRequestTypeDef = TypedDict(
-    "SendSerialConsoleSSHPublicKeyRequestRequestTypeDef",
+_RequiredSendSerialConsoleSSHPublicKeyRequestRequestTypeDef = TypedDict(
+    "_RequiredSendSerialConsoleSSHPublicKeyRequestRequestTypeDef",
     {
         "InstanceId": str,
         "SSHPublicKey": str,
-        "SerialPort": NotRequired[int],
     },
 )
+_OptionalSendSerialConsoleSSHPublicKeyRequestRequestTypeDef = TypedDict(
+    "_OptionalSendSerialConsoleSSHPublicKeyRequestRequestTypeDef",
+    {
+        "SerialPort": int,
+    },
+    total=False,
+)
+
+
+class SendSerialConsoleSSHPublicKeyRequestRequestTypeDef(
+    _RequiredSendSerialConsoleSSHPublicKeyRequestRequestTypeDef,
+    _OptionalSendSerialConsoleSSHPublicKeyRequestRequestTypeDef,
+):
+    pass
+
 
 SendSerialConsoleSSHPublicKeyResponseTypeDef = TypedDict(
     "SendSerialConsoleSSHPublicKeyResponseTypeDef",
